# Contributing to mockgcp

## Missing features

To find missing features that you could implement, visit:

- our public [Trello board](https://trello.com/b/7cK9emg4/mockgcp) or
- our [IMLEMENTATION_COVERAGE](https://github.com/alexandraabbas/mock-gcp/blob/master/IMLEMENTATION_COVERAGE.md) list
  and pick a ticket or an unimplemented class or method.

If you would like to implement a feature that is not in either of the above then create an issue describing what's missing and how would you implement it.

## Getting started

Use the Makefile to get started. First, install the requirements using `make init`. Run tests locally using `make tests`. Run the linter using `make lint`.

## What is "done"?

Before creating a pull request go through the checkpoints below.

- [ ] Have you implemented unit tests for your methods?
- [ ] Have you imeplemented unit tests for edge cases?
- [ ] If applicable, have you added documentation to your methods/[README.md](https://github.com/alexandraabbas/mock-gcp/blob/master/README.md)?
- [ ] Have you updated [IMPLEMENTATION_COVERAGE.md](https://github.com/alexandraabbas/mock-gcp/blob/master/IMLEMENTATION_COVERAGE.md)?
- [ ] If you have used external libraries (try to minimise these), have you added them to [requirements.txt](https://github.com/alexandraabbas/mock-gcp/blob/master/requirements.txt)?

If all these are checked, create a pull request. We'll review your code and merge your branch when it's finished.

## Releasing a new version

TBC...
